From 555cbf8dbf18837df803154d9b2bb22d339b4f85 Mon Sep 17 00:00:00 2001
From: Peter Smith <peter.b.smith@fujitsu.com>
Date: Fri, 26 Feb 2021 13:23:40 +1100
Subject: [PATCH v44] Tablesync early exit.

Give the tablesync worker an opportunity to see if it can exit immediately
(because it has already caught-up) without it needing to process a message
first before discovering that.
---
 src/backend/replication/logical/worker.c | 10 ++++++++++
 1 file changed, 10 insertions(+)

diff --git a/src/backend/replication/logical/worker.c b/src/backend/replication/logical/worker.c
index f837d71..5a0b806 100644
--- a/src/backend/replication/logical/worker.c
+++ b/src/backend/replication/logical/worker.c
@@ -2407,6 +2407,16 @@ LogicalRepApplyLoop(XLogRecPtr last_received)
 	bool		ping_sent = false;
 	TimeLineID	tli;
 
+	if (am_tablesync_worker())
+	{
+		/*
+		 * Give the tablesync worker an opportunity see if it can immediately
+		 * exit, instead of always handling a message (which maybe the apply
+		 * worker could have handled).
+		 */
+		process_syncing_tables(last_received);
+	}
+
 	/*
 	 * Init the ApplyMessageContext which we clean up after each replication
 	 * protocol message.
-- 
1.8.3.1

